from wbfdm.models import Classification, ClassificationGroup

CLASSIFICATIONS = [
    {
        "sector id": "1",
        "sector": "Agriculture",
        "industry id": "5",
        "industry": "Agricultural products & related activities",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "1",
        "sector": "Agriculture",
        "industry id": "10",
        "industry": "Animal Production",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "1",
        "sector": "Agriculture",
        "industry id": "49",
        "industry": "Crop Production",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "6",
        "industry": "Air",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "17",
        "industry": "Automobile Manufacturing",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "18",
        "industry": "Automobile Parts",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "141",
        "industry": "Other Transportation",
        "subindustry id": "54",
        "subindustry": "Commercial Ships",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "141",
        "industry": "Other Transportation",
        "subindustry id": "177",
        "subindustry": "Motorcycle & Small Engine Vehicles",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "141",
        "industry": "Other Transportation",
        "subindustry id": "235",
        "subindustry": "Recreational Vehicles",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "191",
        "industry": "Train",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "192",
        "industry": "Transportation Services",
        "subindustry id": "13",
        "subindustry": "Airline related services",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "192",
        "industry": "Transportation Services",
        "subindustry id": "103",
        "subindustry": "Freight forwarding & courier services",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "192",
        "industry": "Transportation Services",
        "subindustry id": "141",
        "subindustry": "Infrastructure Management Services",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "192",
        "industry": "Transportation Services",
        "subindustry id": "155",
        "subindustry": "Logistics services",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "192",
        "industry": "Transportation Services",
        "subindustry id": "163",
        "subindustry": "Marine Shipping & Management Services",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "192",
        "industry": "Transportation Services",
        "subindustry id": "283",
        "subindustry": "Supply Chain Management Services",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "192",
        "industry": "Transportation Services",
        "subindustry id": "288",
        "subindustry": "Taxi",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "192",
        "industry": "Transportation Services",
        "subindustry id": "302",
        "subindustry": "Trucking related services",
    },
    {
        "sector id": "2",
        "sector": "Automotive & Transportation",
        "industry id": "194",
        "industry": "Trucking",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "3",
        "industry": "Advertising",
        "subindustry id": " Marketing & PR",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "34",
        "industry": "Commercial Printing",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "4",
        "subindustry": "Accounting & Finance Services",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "37",
        "subindustry": "Business Process Outsourcing (BPO)",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "148",
        "subindustry": "Knowledge Process Outsourcing (KPO)",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "160",
        "subindustry": "Management & Strategy Consulting",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "227",
        "subindustry": "Product Development & Design",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "229",
        "subindustry": "Project Management",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "233",
        "subindustry": "QA & Testing",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "332",
        "subindustry": "Research",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "333",
        "subindustry": "Market",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "334",
        "subindustry": "Business Performance Management",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "43",
        "industry": "Consulting & Outsourcing",
        "subindustry id": "335",
        "subindustry": "Supply Chain",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "65",
        "industry": "Education & Training (business)",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "100",
        "industry": "HR & Staffing",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "102",
        "industry": "Information & Records Management",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "111",
        "industry": "Legal Services",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "133",
        "industry": "Office furniture & equipment",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "135",
        "industry": "Office Supplies",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "197",
        "industry": "Wholesale",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "201",
        "industry": "Packaging",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "202",
        "industry": "Electronic Equipment & Components",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "203",
        "industry": "Facilities",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "3",
        "sector": "Business Products & Services",
        "industry id": "204",
        "industry": "Information Services",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "37",
        "industry": "Computer & Technology Leasing Services",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "38",
        "industry": "Computer Networking Equipment",
        "subindustry id": "186",
        "subindustry": "Network Access & Communication Devices",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "38",
        "industry": "Computer Networking Equipment",
        "subindustry id": "187",
        "subindustry": "Network Security Hardware",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "38",
        "industry": "Computer Networking Equipment",
        "subindustry id": "244",
        "subindustry": "Routing & Switching Equipment",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "38",
        "industry": "Computer Networking Equipment",
        "subindustry id": "280",
        "subindustry": "Storage Networking Equipment",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "38",
        "industry": "Computer Networking Equipment",
        "subindustry id": "316",
        "subindustry": "Wireless Networking",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "39",
        "industry": "Computer Product Distribution & Support Services",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "40",
        "industry": "Computer Storage & Peripherals",
        "subindustry id": "60",
        "subindustry": "Computer Displays & Projectors",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "40",
        "industry": "Computer Storage & Peripherals",
        "subindustry id": "61",
        "subindustry": "Computer Input Devices & Speakers",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "40",
        "industry": "Computer Storage & Peripherals",
        "subindustry id": "215",
        "subindustry": "Personal Storage Drives",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "40",
        "industry": "Computer Storage & Peripherals",
        "subindustry id": "225",
        "subindustry": "Printing & Imaging Equipment",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "93",
        "industry": "Handheld Computers & Accessories",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "108",
        "industry": "IT Services",
        "subindustry id": "74",
        "subindustry": "Data Storage & Security",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "108",
        "industry": "IT Services",
        "subindustry id": "140",
        "subindustry": "Infrastructure & Hosting",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "108",
        "industry": "IT Services",
        "subindustry id": "145",
        "subindustry": "IT Management & Helpdesk",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "108",
        "industry": "IT Services",
        "subindustry id": "306",
        "subindustry": "Virtualization",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "108",
        "industry": "IT Services",
        "subindustry id": "331",
        "subindustry": "Web Design & Development",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "108",
        "industry": "IT Services",
        "subindustry id": "339",
        "subindustry": "Networking",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "108",
        "industry": "IT Services",
        "subindustry id": "340",
        "subindustry": "IT Solutions & Software Development",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "144",
        "industry": "Personal Computers & Notebooks",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "169",
        "industry": "Servers & Mainframes",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "173",
        "industry": "Specialty Computer Hardware",
        "subindustry id": "23",
        "subindustry": "ATMs",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "173",
        "industry": "Specialty Computer Hardware",
        "subindustry id": "173",
        "subindustry": "Military & Industrial Computer Systems",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "173",
        "industry": "Specialty Computer Hardware",
        "subindustry id": "222",
        "subindustry": "Point of Sales & Retail Computer Systems",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "179",
        "industry": "Supercomputers",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "199",
        "industry": "Workstations & Thin Clients",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "4",
        "sector": "Computer Hardware & Services",
        "industry id": "209",
        "industry": "Gaming",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "12",
        "industry": "Appliances",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "19",
        "industry": "Automotive Services",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "20",
        "industry": "Baby Supplies",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "28",
        "industry": "Car & Truck Rental",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "31",
        "industry": "Clothing & Accessories",
        "subindustry id": "1",
        "subindustry": "Accessories",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "31",
        "industry": "Clothing & Accessories",
        "subindustry id": "43",
        "subindustry": "Children’s Clothing",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "31",
        "industry": "Clothing & Accessories",
        "subindustry id": "101",
        "subindustry": "Footwear",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "31",
        "industry": "Clothing & Accessories",
        "subindustry id": "168",
        "subindustry": "Men’s Clothing",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "31",
        "industry": "Clothing & Accessories",
        "subindustry id": "320",
        "subindustry": "Women’s Clothing",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "44",
        "industry": "Consumer Electronics",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "66",
        "industry": "Education & Training (non-internet/mobile)",
        "subindustry id": "42",
        "subindustry": "Childcare Services and Children’s Schooling",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "66",
        "industry": "Education & Training (non-internet/mobile)",
        "subindustry id": "47",
        "subindustry": "Colleges & Universities",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "66",
        "industry": "Education & Training (non-internet/mobile)",
        "subindustry id": "297",
        "subindustry": "Training Services",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "95",
        "industry": "Health & Wellness (non-internet/mobile)",
        "subindustry id": "276",
        "subindustry": "Sporting Goods & Equipment",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "95",
        "industry": "Health & Wellness (non-internet/mobile)",
        "subindustry id": "313",
        "subindustry": "Weight & Health Management",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "99",
        "industry": "Household",
        "subindustry id": "44",
        "subindustry": "Cleaning Products",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "99",
        "industry": "Household",
        "subindustry id": "104",
        "subindustry": "Furnishings & Decoration",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "99",
        "industry": "Household",
        "subindustry id": "129",
        "subindustry": "Housewares",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "99",
        "industry": "Household",
        "subindustry id": "294",
        "subindustry": "Tools",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "109",
        "industry": "Jewelry",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "128",
        "industry": "Music Instruments",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "143",
        "industry": "Personal",
        "subindustry id": "95",
        "subindustry": "Eyewear",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "143",
        "industry": "Personal",
        "subindustry id": "150",
        "subindustry": "Laundry Services",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "143",
        "industry": "Personal",
        "subindustry id": "213",
        "subindustry": "Personal Care Products",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "143",
        "industry": "Personal",
        "subindustry id": "246",
        "subindustry": "Salon Services",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "145",
        "industry": "Pet Products",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "163",
        "industry": "School & Art Supplies",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "187",
        "industry": "Tobacco",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "189",
        "industry": "Toys & Games",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "193",
        "industry": "Travel Services (non-internet/mobile)",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "195",
        "industry": "Veterinary Care Services",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "206",
        "industry": "Sporting Goods",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "5",
        "sector": "Consumer Products & Services",
        "industry id": "207",
        "industry": "Home Furnishings & Accessories",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "257",
        "subindustry": "Semiconductor Equipment",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "258",
        "subindustry": "Semiconductors",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "259",
        "subindustry": "Semiconductors: Analog Chips",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "260",
        "subindustry": "Semiconductors: Audio Chips & Boards",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "261",
        "subindustry": "Semiconductors: Communications Chips",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "262",
        "subindustry": "Semiconductors: Components",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "263",
        "subindustry": "Semiconductors: Design & Packaging Services",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "264",
        "subindustry": "Semiconductors: Graphics",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "265",
        "subindustry": "Semiconductors: Memory",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "266",
        "subindustry": "Semiconductors: Microprocessors",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "341",
        "subindustry": "Semiconductors: Integrated Circuits",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "30",
        "industry": "Chips & Semiconductors",
        "subindustry id": "342",
        "subindustry": "Semiconductors: Sensors",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "70",
        "industry": "Electrical Product Distribution",
        "subindustry id": "178",
        "subindustry": "Motors & Motor Drives",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "70",
        "industry": "Electrical Product Distribution",
        "subindustry id": "223",
        "subindustry": "Power Generation & Storage",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "70",
        "industry": "Electrical Product Distribution",
        "subindustry id": "286",
        "subindustry": "Switches & Connectors",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "70",
        "industry": "Electrical Product Distribution",
        "subindustry id": "298",
        "subindustry": "Transformers & Power Conversion",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "71",
        "industry": "Electrical Products",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "72",
        "industry": "Electronic Components",
        "subindustry id": "57",
        "subindustry": "Component Distribution",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "72",
        "industry": "Electronic Components",
        "subindustry id": "84",
        "subindustry": "Display Components",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "72",
        "industry": "Electronic Components",
        "subindustry id": "154",
        "subindustry": "Lighting & LED",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "72",
        "industry": "Electronic Components",
        "subindustry id": "198",
        "subindustry": "Optical Switches & Transmission Components",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "72",
        "industry": "Electronic Components",
        "subindustry id": "315",
        "subindustry": "Wireless Communications",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "72",
        "industry": "Electronic Components",
        "subindustry id": "336",
        "subindustry": "Processors",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "73",
        "industry": "Electronic Manufacturing Services",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "74",
        "industry": "Electronic test",
        "subindustry id": " measurement & monitoring",
        "subindustry": "",
    },
    {
        "sector id": "6",
        "sector": "Electronics",
        "industry id": "181",
        "industry": "Technical & Scientific Instrumentation",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "69",
        "industry": "Electric",
        "subindustry id": "102",
        "subindustry": "Fossil Fuels",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "69",
        "industry": "Electric",
        "subindustry id": "192",
        "subindustry": "Nuclear",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "69",
        "industry": "Electric",
        "subindustry id": "299",
        "subindustry": "Transmission & Distribution",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "77",
        "industry": "Energy Efficiency",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "78",
        "industry": "Energy Storage",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "79",
        "industry": "Energy Trading & Marketing",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "130",
        "industry": "Natural Gas Utilities",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "136",
        "industry": "Oil & Gas Production & Exploration",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "137",
        "industry": "Oil & Gas Refining & Distribution",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "138",
        "industry": "Oil & Gas Storage & Transport",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "156",
        "industry": "Renewables",
        "subindustry id": "32",
        "subindustry": "Bio-energy",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "156",
        "industry": "Renewables",
        "subindustry id": "114",
        "subindustry": "Geothermal",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "156",
        "industry": "Renewables",
        "subindustry id": "132",
        "subindustry": "Hydrogen/Fuel Cell",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "156",
        "industry": "Renewables",
        "subindustry id": "139",
        "subindustry": "Infrastructure",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "156",
        "industry": "Renewables",
        "subindustry id": "193",
        "subindustry": "Ocean & Hydro",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "156",
        "industry": "Renewables",
        "subindustry id": "202",
        "subindustry": "Other Renewables",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "156",
        "industry": "Renewables",
        "subindustry id": "270",
        "subindustry": "Solar",
    },
    {
        "sector id": "7",
        "sector": "Energy & Utilities",
        "industry id": "156",
        "industry": "Renewables",
        "subindustry id": "314",
        "subindustry": "Wind",
    },
    {
        "sector id": "8",
        "sector": "Environmental Services & Equipment",
        "industry id": "81",
        "industry": "Environmental & Energy Consulting",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "8",
        "sector": "Environmental Services & Equipment",
        "industry id": "94",
        "industry": "Hazardous Waste Services",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "8",
        "sector": "Environmental Services & Equipment",
        "industry id": "154",
        "industry": "Recycling",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "8",
        "sector": "Environmental Services & Equipment",
        "industry id": "155",
        "industry": "Remediation & Environmental Cleanup",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "8",
        "sector": "Environmental Services & Equipment",
        "industry id": "171",
        "industry": "Solid Waste",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "1",
        "industry": "Accounting",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "15",
        "industry": "Asset/Financial Management",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "48",
        "industry": "Credit & Collections",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "104",
        "industry": "Insurance",
        "subindustry id": "142",
        "subindustry": "Insurance Broker",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "104",
        "industry": "Insurance",
        "subindustry id": "153",
        "subindustry": "Life Insurance",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "104",
        "industry": "Insurance",
        "subindustry id": "200",
        "subindustry": "Other Insurance",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "104",
        "industry": "Insurance",
        "subindustry id": "230",
        "subindustry": "Property & Casualty",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "104",
        "industry": "Insurance",
        "subindustry id": "236",
        "subindustry": "Reinsurance",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "104",
        "industry": "Insurance",
        "subindustry id": "243",
        "subindustry": "Risk Management",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "104",
        "industry": "Insurance",
        "subindustry id": "337",
        "subindustry": "Health Insurance",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "106",
        "industry": "Investment Banking",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "107",
        "industry": "Investment Firms & Funds",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "113",
        "industry": "Lending",
        "subindustry id": "48",
        "subindustry": "Commercial",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "113",
        "industry": "Lending",
        "subindustry id": "65",
        "subindustry": "Consumer",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "113",
        "industry": "Lending",
        "subindustry id": "172",
        "subindustry": "Microfinance",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "142",
        "industry": "Payments (non-internet/mobile)",
        "subindustry id": "144",
        "subindustry": "Issuer",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "142",
        "industry": "Payments (non-internet/mobile)",
        "subindustry id": "169",
        "subindustry": "Merchant Services",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "142",
        "industry": "Payments (non-internet/mobile)",
        "subindustry id": "226",
        "subindustry": "Processing",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "153",
        "industry": "Real Estate",
        "subindustry id": "50",
        "subindustry": "Commercial Property Management",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "153",
        "industry": "Real Estate",
        "subindustry id": "51",
        "subindustry": "Commercial Real Estate Brokerage",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "153",
        "industry": "Real Estate",
        "subindustry id": "52",
        "subindustry": "Commercial Real Estate Development",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "153",
        "industry": "Real Estate",
        "subindustry id": "53",
        "subindustry": "Commercial Real Estate Investment",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "153",
        "industry": "Real Estate",
        "subindustry id": "237",
        "subindustry": "REITs",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "153",
        "industry": "Real Estate",
        "subindustry id": "238",
        "subindustry": "Residential Property Management",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "153",
        "industry": "Real Estate",
        "subindustry id": "239",
        "subindustry": "Residential Real Estate Brokerage",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "153",
        "industry": "Real Estate",
        "subindustry id": "240",
        "subindustry": "Residential Real Estate Development",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "153",
        "industry": "Real Estate",
        "subindustry id": "241",
        "subindustry": "Residential Real Estate Investment",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "160",
        "industry": "Retail Banking",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "165",
        "industry": "Securities Brokers & Traders",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "9",
        "sector": "Financial",
        "industry id": "177",
        "industry": "Stock Exchanges",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "7",
        "industry": "Alcoholic Beverages",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "24",
        "industry": "Bottling & Distribution",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "26",
        "industry": "Candy & snackfoods",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "27",
        "industry": "Canned and frozen foods",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "51",
        "industry": "Dairy products",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "85",
        "industry": "Food safety & preservation",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "86",
        "industry": "Foodservice",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "87",
        "industry": "Fresh foods",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "103",
        "industry": "Ingredients",
        "subindustry id": " flavoring & condiments",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "117",
        "industry": "Meat",
        "subindustry id": " Fish",
        "subindustry": " Seafood & Alternative Proteins",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "132",
        "industry": "Non-alcoholic beverages",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "10",
        "sector": "Food & Beverages",
        "industry id": "198",
        "industry": "Wholesale food distributors",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "8",
        "industry": "Alternative Medicine",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "23",
        "industry": "Biotechnology",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "54",
        "industry": "Dental Products & Services",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "59",
        "industry": "Disease Diagnosis",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "60",
        "industry": "Drug Delivery",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "61",
        "industry": "Drug Development",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "62",
        "industry": "Drug Discovery",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "63",
        "industry": "Drug Manufacturing",
        "subindustry id": "79",
        "subindustry": "Diagnostic Substances",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "63",
        "industry": "Drug Manufacturing",
        "subindustry id": "113",
        "subindustry": "Generics",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "63",
        "industry": "Drug Manufacturing",
        "subindustry id": "199",
        "subindustry": "OTC Medications",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "63",
        "industry": "Drug Manufacturing",
        "subindustry id": "307",
        "subindustry": "Vitamins",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "68",
        "industry": "Elective & Aesthetic Medicine",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "96",
        "industry": "Healthcare Plans",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "118",
        "industry": "Medical Devices & Equipment",
        "subindustry id": "78",
        "subindustry": "Device Design & Manufacturing",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "118",
        "industry": "Medical Devices & Equipment",
        "subindustry id": "133",
        "subindustry": "Imaging & Diagnostic Equipment",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "118",
        "industry": "Medical Devices & Equipment",
        "subindustry id": "167",
        "subindustry": "Medical Supplies",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "118",
        "industry": "Medical Devices & Equipment",
        "subindustry id": "201",
        "subindustry": "Other Medical Devices",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "118",
        "industry": "Medical Devices & Equipment",
        "subindustry id": "209",
        "subindustry": "Patient Monitoring",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "118",
        "industry": "Medical Devices & Equipment",
        "subindustry id": "231",
        "subindustry": "Prosthetics",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "118",
        "industry": "Medical Devices & Equipment",
        "subindustry id": "284",
        "subindustry": "Surgical Devices",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "118",
        "industry": "Medical Devices & Equipment",
        "subindustry id": "293",
        "subindustry": "Therapeutic Devices",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "119",
        "industry": "Medical Equipment & Supplies",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "120",
        "industry": "Medical Facilities & Services",
        "subindustry id": "121",
        "subindustry": "Health care plans",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "120",
        "industry": "Medical Facilities & Services",
        "subindustry id": "127",
        "subindustry": "Home Healthcare",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "120",
        "industry": "Medical Facilities & Services",
        "subindustry id": "128",
        "subindustry": "Hospitals",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "120",
        "industry": "Medical Facilities & Services",
        "subindustry id": "156",
        "subindustry": "Long-term Care",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "120",
        "industry": "Medical Facilities & Services",
        "subindustry id": "164",
        "subindustry": "Medical Laboratories & Research",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "120",
        "industry": "Medical Facilities & Services",
        "subindustry id": "165",
        "subindustry": "Medical Practice Management & Services",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "120",
        "industry": "Medical Facilities & Services",
        "subindustry id": "166",
        "subindustry": "Medical Practitioners",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "120",
        "industry": "Medical Facilities & Services",
        "subindustry id": "224",
        "subindustry": "Prescription Benefits Management",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "120",
        "industry": "Medical Facilities & Services",
        "subindustry id": "271",
        "subindustry": "Specialized Healthcare Services",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "121",
        "industry": "Medical Information",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "122",
        "industry": "Medical Product Distribution",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "146",
        "industry": "Pharmaceutical Distribution & Wholesale",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "147",
        "industry": "Pharmaceuticals / Drugs",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "11",
        "sector": "Healthcare",
        "industry id": "210",
        "industry": "Stealth Mode",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "4",
        "industry": "Aerospace & Defense",
        "subindustry id": "49",
        "subindustry": "Commercial aircraft manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "4",
        "industry": "Aerospace & Defense",
        "subindustry id": "159",
        "subindustry": "Maintenance & Services",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "4",
        "industry": "Aerospace & Defense",
        "subindustry id": "174",
        "subindustry": "Military aircraft manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "4",
        "industry": "Aerospace & Defense",
        "subindustry id": "206",
        "subindustry": "Other weapon design & manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "4",
        "industry": "Aerospace & Defense",
        "subindustry id": "208",
        "subindustry": "Parts Manufacturing & Distribution",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "4",
        "industry": "Aerospace & Defense",
        "subindustry id": "267",
        "subindustry": "Ship & Submarine manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "21",
        "industry": "Basic Materials",
        "subindustry id": "12",
        "subindustry": "Agricultural Chemicals",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "21",
        "industry": "Basic Materials",
        "subindustry id": "40",
        "subindustry": "Chemical Distribution",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "21",
        "industry": "Basic Materials",
        "subindustry id": "41",
        "subindustry": "Chemicals",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "21",
        "industry": "Basic Materials",
        "subindustry id": "171",
        "subindustry": "Metals",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "21",
        "industry": "Basic Materials",
        "subindustry id": "220",
        "subindustry": "Plastics & Fibers",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "21",
        "industry": "Basic Materials",
        "subindustry id": "272",
        "subindustry": "Specialty Chemicals",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "21",
        "industry": "Basic Materials",
        "subindustry id": "287",
        "subindustry": "Synthetics",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "42",
        "industry": "Construction",
        "subindustry id": "64",
        "subindustry": "Construction & Design Services",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "42",
        "industry": "Construction",
        "subindustry id": "112",
        "subindustry": "General Building Materials",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "42",
        "industry": "Construction",
        "subindustry id": "157",
        "subindustry": "Lumber & Wood Production",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "42",
        "industry": "Construction",
        "subindustry id": "221",
        "subindustry": "Plumbing & HVAC",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "85",
        "subindustry": "Diversified Machinery Manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "96",
        "subindustry": "Farm & Construction Machinery Manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "124",
        "subindustry": "Heavy Equipment Manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "134",
        "subindustry": "Industrial Equipment & Component Manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "135",
        "subindustry": "Industrial Equipment Leasing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "136",
        "subindustry": "Industrial Machinery & Equipment Distribution",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "149",
        "subindustry": "Laboratory & Research Equipment Manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "158",
        "subindustry": "Machine Tools & Accessories Manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "170",
        "subindustry": "Metal Fabrication",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "207",
        "subindustry": "Paper & Paper Product Manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "245",
        "subindustry": "Rubber & Plastic Product Manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "115",
        "industry": "Manufacturing",
        "subindustry id": "292",
        "subindustry": "Textile Manufacturing",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "149",
        "industry": "Pollution & Treatment Controls",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "196",
        "industry": "Water",
        "subindustry id": "77",
        "subindustry": "Desalination",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "196",
        "industry": "Water",
        "subindustry id": "232",
        "subindustry": "Purification",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "196",
        "industry": "Water",
        "subindustry id": "309",
        "subindustry": "Waste Water Treatment",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "196",
        "industry": "Water",
        "subindustry id": "310",
        "subindustry": "Water Distribution",
    },
    {
        "sector id": "12",
        "sector": "Industrial",
        "industry id": "208",
        "industry": "Machinery & Equipment",
        "subindustry id": "338",
        "subindustry": "Robotics",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "15",
        "subindustry": "Apparel & Accessories",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "24",
        "subindustry": "Auction & Classifieds",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "26",
        "subindustry": "Auto",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "28",
        "subindustry": "B2B Commerce",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "58",
        "subindustry": "Computer & Software",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "80",
        "subindustry": "Digital Goods",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "82",
        "subindustry": "Discount",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "87",
        "subindustry": "eCommerce enablement",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "90",
        "subindustry": "Electronics & Appliances",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "94",
        "subindustry": "Events & Ticketing",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "99",
        "subindustry": "Food & Grocery",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "110",
        "subindustry": "Gasoline",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "125",
        "subindustry": "Home Furnishings & Improvement",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "146",
        "subindustry": "Jewelry",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "184",
        "subindustry": "Music",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "194",
        "subindustry": "Office Products",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "204",
        "subindustry": "Other Retail",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "216",
        "subindustry": "Pharmacies",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "274",
        "subindustry": "Sporting Goods",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "295",
        "subindustry": "Toys & Games",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "300",
        "subindustry": "Travel (internet)",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "325",
        "subindustry": "Marketplace",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "326",
        "subindustry": "Multi-Product",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "64",
        "industry": "eCommerce",
        "subindustry id": "343",
        "subindustry": "Comparison Shopping",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "2",
        "subindustry": "Accounting & Finance",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "5",
        "subindustry": "Adult Entertainment",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "8",
        "subindustry": "Advertising Network or Exchange",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "10",
        "subindustry": "Advertising",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "17",
        "subindustry": "Application & Data Integration",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "21",
        "subindustry": "Asset & Financial Management & Trading",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "30",
        "subindustry": "Billing",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "33",
        "subindustry": "Browser Software/Plugins",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "35",
        "subindustry": "Business Intelligence",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "45",
        "subindustry": "Collaboration & Project Management",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "55",
        "subindustry": "Compliance",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "62",
        "subindustry": "Conferencing & Communication",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "66",
        "subindustry": "Content Management",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "68",
        "subindustry": "Customer Relationship Management",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "70",
        "subindustry": "Data & Document Management",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "73",
        "subindustry": "Data Storage",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "75",
        "subindustry": "Database Management",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "86",
        "subindustry": "Domain & SEO Services",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "88",
        "subindustry": "Education & Training",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "92",
        "subindustry": "Email",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "105",
        "subindustry": "Gambling",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "108",
        "subindustry": "Gaming",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "115",
        "subindustry": "Government",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "117",
        "subindustry": "Green/Environmental",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "119",
        "subindustry": "Health & Wellness",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "122",
        "subindustry": "Healthcare",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "130",
        "subindustry": "HR & Workforce Management",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "137",
        "subindustry": "Information Providers & Portals",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "143",
        "subindustry": "Internet Service Provider",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "151",
        "subindustry": "Legal",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "161",
        "subindustry": "Manufacturing",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "176",
        "subindustry": "Monitoring & Security",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "180",
        "subindustry": "Multimedia & Graphics",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "182",
        "subindustry": "Music",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "188",
        "subindustry": "Networking & Connectivity",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "190",
        "subindustry": "News & Discussion",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "196",
        "subindustry": "Operating Systems & Utility",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "210",
        "subindustry": "Payments",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "212",
        "subindustry": "Personal & Professional Development",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "218",
        "subindustry": "Photo",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "242",
        "subindustry": "Retail & Inventory",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "248",
        "subindustry": "Scientific",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "250",
        "subindustry": "Search",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "268",
        "subindustry": "Social",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "277",
        "subindustry": "Sports",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "281",
        "subindustry": "Supply Chain & Logistics",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "290",
        "subindustry": "Testing",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "303",
        "subindustry": "Video",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "311",
        "subindustry": "Web Development",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "312",
        "subindustry": "Website hosting",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "321",
        "subindustry": "Travel",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "105",
        "industry": "Internet Software & Services",
        "subindustry id": "323",
        "subindustry": "Real Estate",
    },
    {
        "sector id": "13",
        "sector": "Internet",
        "industry id": "212",
        "industry": "Stealth Mode",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "80",
        "industry": "Entertainment",
        "subindustry id": "7",
        "subindustry": "Adult Entertainment (non-internet/mobile)",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "80",
        "industry": "Entertainment",
        "subindustry id": "14",
        "subindustry": "Amusement Parks",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "80",
        "industry": "Entertainment",
        "subindustry id": "107",
        "subindustry": "Gambling (non-internet/mobile)",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "80",
        "industry": "Entertainment",
        "subindustry id": "179",
        "subindustry": "Movie Theaters",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "114",
        "industry": "Lodging",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "158",
        "industry": "Restaurants",
        "subindustry id": "39",
        "subindustry": "Casual Dining",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "158",
        "industry": "Restaurants",
        "subindustry id": "203",
        "subindustry": "Other Restaurants",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "158",
        "industry": "Restaurants",
        "subindustry id": "234",
        "subindustry": "Quick Service",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "158",
        "industry": "Restaurants",
        "subindustry id": "273",
        "subindustry": "Specialty Restaurants",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "175",
        "industry": "Sports & Recreation",
        "subindustry id": "97",
        "subindustry": "Fitness",
    },
    {
        "sector id": "14",
        "sector": "Leisure",
        "industry id": "175",
        "industry": "Sports & Recreation",
        "subindustry id": "228",
        "subindustry": "Professional Sports Teams",
    },
    {
        "sector id": "15",
        "sector": "Media (Traditional)",
        "industry id": "83",
        "industry": "Film & Video",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "15",
        "sector": "Media (Traditional)",
        "industry id": "127",
        "industry": "Music",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "15",
        "sector": "Media (Traditional)",
        "industry id": "151",
        "industry": "Publishing",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "15",
        "sector": "Media (Traditional)",
        "industry id": "152",
        "industry": "Radio",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "15",
        "sector": "Media (Traditional)",
        "industry id": "185",
        "industry": "Television",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "16",
        "sector": "Metals & Mining",
        "industry id": "9",
        "industry": "Aluminum",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "16",
        "sector": "Metals & Mining",
        "industry id": "32",
        "industry": "Coal",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "16",
        "sector": "Metals & Mining",
        "industry id": "47",
        "industry": "Copper",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "16",
        "sector": "Metals & Mining",
        "industry id": "56",
        "industry": "Diamond & Precious Stones",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "16",
        "sector": "Metals & Mining",
        "industry id": "123",
        "industry": "Metal & Mining Brokers/Distribution",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "16",
        "sector": "Metals & Mining",
        "industry id": "150",
        "industry": "Precious Metals",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "16",
        "sector": "Metals & Mining",
        "industry id": "172",
        "industry": "Specialty",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "16",
        "sector": "Metals & Mining",
        "industry id": "176",
        "industry": "Steel",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "82",
        "industry": "Fiber Optics",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "16",
        "subindustry": "Apparel & Accessories",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "25",
        "subindustry": "Auction & Classifieds",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "27",
        "subindustry": "Auto",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "29",
        "subindustry": "B2B Commerce",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "59",
        "subindustry": "Computer & Software",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "81",
        "subindustry": "Digital Goods",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "83",
        "subindustry": "Discount",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "91",
        "subindustry": "Electronics & Appliances",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "100",
        "subindustry": "Food & Grocery",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "111",
        "subindustry": "Gasoline",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "126",
        "subindustry": "Home Furnishings & Improvement",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "147",
        "subindustry": "Jewelry",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "175",
        "subindustry": "Mobile Commerce enablement",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "185",
        "subindustry": "Music",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "195",
        "subindustry": "Office Products",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "205",
        "subindustry": "Other Retail",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "217",
        "subindustry": "Pharmacies",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "275",
        "subindustry": "Sporting Goods",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "296",
        "subindustry": "Toys & Games",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "301",
        "subindustry": "Travel (mobile)",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "327",
        "subindustry": "Marketplace",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "328",
        "subindustry": "Multi-Product",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "124",
        "industry": "Mobile Commerce",
        "subindustry id": "344",
        "subindustry": "Comparison Shopping",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "3",
        "subindustry": "Accounting & Finance",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "6",
        "subindustry": "Adult Entertainment",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "9",
        "subindustry": "Advertising Network or Exchange",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "11",
        "subindustry": "Advertising",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "18",
        "subindustry": "Application & Data Integration",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "20",
        "subindustry": "Application Development",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "22",
        "subindustry": "Asset & Financial Management & Trading",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "31",
        "subindustry": "Billing",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "34",
        "subindustry": "Browser Software/Plugins",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "36",
        "subindustry": "Business Intelligence",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "46",
        "subindustry": "Collaboration & Project Management",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "56",
        "subindustry": "Compliance",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "63",
        "subindustry": "Conferencing & Communication",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "67",
        "subindustry": "Content Management",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "69",
        "subindustry": "Customer Relationship Management",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "71",
        "subindustry": "Data & Document Management",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "76",
        "subindustry": "Database Management",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "89",
        "subindustry": "Education & Training",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "93",
        "subindustry": "Email",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "106",
        "subindustry": "Gambling",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "109",
        "subindustry": "Gaming",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "116",
        "subindustry": "Government",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "118",
        "subindustry": "Green/Environmental",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "120",
        "subindustry": "Health & Wellness",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "123",
        "subindustry": "Healthcare",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "131",
        "subindustry": "HR & Workforce Management",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "138",
        "subindustry": "Information Providers & Portals",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "152",
        "subindustry": "Legal",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "162",
        "subindustry": "Manufacturing",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "181",
        "subindustry": "Multimedia & Graphics",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "183",
        "subindustry": "Music",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "189",
        "subindustry": "Networking & Connectivity",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "191",
        "subindustry": "News & Discussion",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "197",
        "subindustry": "Operating Systems & Utility",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "211",
        "subindustry": "Payments",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "219",
        "subindustry": "Photo",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "249",
        "subindustry": "Scientific",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "251",
        "subindustry": "Search",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "252",
        "subindustry": "Security",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "269",
        "subindustry": "Social",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "278",
        "subindustry": "Sports",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "279",
        "subindustry": "Storage & Systems Management",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "282",
        "subindustry": "Supply Chain & Logistics",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "291",
        "subindustry": "Testing",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "304",
        "subindustry": "Video",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "322",
        "subindustry": "Travel",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "324",
        "subindustry": "Real Estate",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "330",
        "subindustry": "Location-Based & Navigation",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "125",
        "industry": "Mobile Software & Services",
        "subindustry id": "345",
        "subindustry": "Point of Sale",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "161",
        "industry": "RFID Systems",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "183",
        "industry": "Telecom Devices & Equipment",
        "subindustry id": "247",
        "subindustry": "Satellite & Broadcast Network Equipment",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "183",
        "industry": "Telecom Devices & Equipment",
        "subindustry id": "289",
        "subindustry": "Telecom Equipment Distribution & Maintenance",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "183",
        "industry": "Telecom Devices & Equipment",
        "subindustry id": "318",
        "subindustry": "Wireless Telecom Equipment",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "183",
        "industry": "Telecom Devices & Equipment",
        "subindustry id": "319",
        "subindustry": "Wireline Telecom Equipment",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "184",
        "industry": "Telecom Services",
        "subindustry id": "38",
        "subindustry": "Cable & Satellite",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "184",
        "industry": "Telecom Services",
        "subindustry id": "72",
        "subindustry": "Data & Broadband",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "184",
        "industry": "Telecom Services",
        "subindustry id": "98",
        "subindustry": "Fixed Line Voice",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "184",
        "industry": "Telecom Services",
        "subindustry id": "305",
        "subindustry": "Video Conferencing",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "184",
        "industry": "Telecom Services",
        "subindustry id": "308",
        "subindustry": "VoIP",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "184",
        "industry": "Telecom Services",
        "subindustry id": "317",
        "subindustry": "Wireless",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "184",
        "industry": "Telecom Services",
        "subindustry id": "329",
        "subindustry": "Diversified & Bundled",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "188",
        "industry": "Towers & Infrastructure",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "17",
        "sector": "Mobile & Telecommunications",
        "industry id": "213",
        "industry": "Stealth Mode",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "11",
        "industry": "Apparel & Accessories",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "16",
        "industry": "Auto",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "29",
        "industry": "Catalog",
        "subindustry id": " Mail Order & TV Sales",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "36",
        "industry": "Computer & Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "46",
        "industry": "Convenience Stores",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "55",
        "industry": "Department Stores",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "57",
        "industry": "Direct sales",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "58",
        "industry": "Discount",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "75",
        "industry": "Electronics & Appliances",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "89",
        "industry": "Gasoline",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "92",
        "industry": "Grocery",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "98",
        "industry": "Home Furnishings & Improvement",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "110",
        "industry": "Jewelry",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "129",
        "industry": "Music",
        "subindustry id": " Video",
        "subindustry": " Books & Entertainment",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "134",
        "industry": "Office Products",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "140",
        "industry": "Other Retail",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "148",
        "industry": "Pharmacies",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "170",
        "industry": "Services",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "174",
        "industry": "Sporting Goods",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "19",
        "sector": "Retail (non-internet/mobile)",
        "industry id": "190",
        "industry": "Toys & Games",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "20",
        "sector": "Risk & Security",
        "industry id": "166",
        "industry": "Security Products",
        "subindustry id": "214",
        "subindustry": "Personal Protective Equipment",
    },
    {
        "sector id": "20",
        "sector": "Risk & Security",
        "industry id": "166",
        "industry": "Security Products",
        "subindustry id": "253",
        "subindustry": "Security & Monitoring Equipment",
    },
    {
        "sector id": "20",
        "sector": "Risk & Security",
        "industry id": "166",
        "industry": "Security Products",
        "subindustry id": "256",
        "subindustry": "Security Systems",
    },
    {
        "sector id": "20",
        "sector": "Risk & Security",
        "industry id": "167",
        "industry": "Security Services",
        "subindustry id": "254",
        "subindustry": "Security Consulting & Advisory",
    },
    {
        "sector id": "20",
        "sector": "Risk & Security",
        "industry id": "167",
        "industry": "Security Services",
        "subindustry id": "255",
        "subindustry": "Security Guard Services",
    },
    {
        "sector id": "20",
        "sector": "Risk & Security",
        "industry id": "167",
        "industry": "Security Services",
        "subindustry id": "285",
        "subindustry": "Surveillance & Investigation",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "2",
        "industry": "Accounting & Finance Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "13",
        "industry": "Application & Data Integration Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "14",
        "industry": "Asset & Financial Management & Trading Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "22",
        "industry": "Billing",
        "subindustry id": " Expense Management and Procurement Software",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "25",
        "industry": "Business Intelligence",
        "subindustry id": " Analytics & Performance Mgmt Software",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "33",
        "industry": "Collaboration & Project Management Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "35",
        "industry": "Compliance",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "41",
        "industry": "Conferencing & Communication Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "45",
        "industry": "Content Management Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "50",
        "industry": "Customer Relationship Management Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "52",
        "industry": "Data & Document Management Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "53",
        "industry": "Database Management Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "67",
        "industry": "Education & Training Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "76",
        "industry": "Email",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "84",
        "industry": "Financial Services Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "88",
        "industry": "Gaming",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "90",
        "industry": "Government Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "91",
        "industry": "Green/Environmental Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "97",
        "industry": "Healthcare Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "101",
        "industry": "HR & Workforce Management Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "112",
        "industry": "Legal Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "116",
        "industry": "Manufacturing",
        "subindustry id": " Warehousing & Industrial Software",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "126",
        "industry": "Multimedia & Graphics",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "131",
        "industry": "Networking & Connectivity Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "139",
        "industry": "Operating Systems & Utility Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "159",
        "industry": "Retail & Inventory Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "162",
        "industry": "Sales & Marketing Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "164",
        "industry": "Scientific",
        "subindustry id": " Engineering Software",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "168",
        "industry": "Security Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "178",
        "industry": "Storage & Systems Management Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "180",
        "industry": "Supply Chain & Logistics Software",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "186",
        "industry": "Testing",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "200",
        "industry": "Real Estate",
        "subindustry id": "",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "205",
        "industry": "Advertising",
        "subindustry id": " Sales & Marketing",
        "subindustry": "",
    },
    {
        "sector id": "21",
        "sector": "Software (non-internet/mobile)",
        "industry id": "211",
        "industry": "Stealth Mode",
        "subindustry id": "",
        "subindustry": "",
    },
]


def import_classification():
    cbinsight_group = ClassificationGroup.objects.get_or_create(
        name="CBinsights", max_depth=2, defaults={"code_level_digits": 3}
    )[0]
    for row in CLASSIFICATIONS:
        try:
            if sector_id := row.get("sector id", None):
                code_aggregated = f"{int(sector_id):03}"
                sector = Classification.objects.get_or_create(
                    code_aggregated=code_aggregated,
                    group=cbinsight_group,
                    defaults={"level_representation": "Sector", "name": row.get("sector", None)},
                )[0]
                if industry_id := row.get("industry id", None):
                    code_aggregated += f"{int(industry_id):03}"
                    industry = Classification.objects.get_or_create(
                        code_aggregated=code_aggregated,
                        group=cbinsight_group,
                        parent=sector,
                        defaults={"level_representation": "Industry", "name": row.get("industry", None)},
                    )[0]

                    if subindustry_id := row.get("subindustry id", None):
                        code_aggregated += f"{int(subindustry_id):03}"
                        Classification.objects.get_or_create(
                            code_aggregated=code_aggregated,
                            group=cbinsight_group,
                            parent=industry,
                            defaults={"level_representation": "Sub-Industry", "name": row.get("subindustry", None)},
                        )[0]
        except Exception as e:
            print(e)  # noqa: T201
