# Generated by Django 5.0.14 on 2025-08-27 07:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wbfdm', '0031_exchange_apply_round_lot_size_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='instrumentprice',
            name='outstanding_shares',
            field=models.DecimalField(blank=True, decimal_places=4, help_text='The amount of outstanding share for this instrument', max_digits=16, null=True, verbose_name='Outstanding Shares'),
        ),
    ]
