# Generated by Django 4.2.6 on 2023-10-30 12:39

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("wbfdm", "0007_instrument_country_instrument_currency_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="Controversy",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("external_id", models.CharField(max_length=512, unique=True)),
                ("headline", models.TextField(verbose_name="Headline")),
                ("description", models.TextField(verbose_name="Description")),
                ("source", models.CharField(max_length=512, verbose_name="Source")),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("ONGOING", "Ongoing"),
                            ("PARTIALLY_CONCLUDED", "Partially Concluded"),
                            ("CONCLUDED", "Concluded"),
                        ],
                        max_length=64,
                        verbose_name="Status",
                    ),
                ),
                (
                    "type",
                    models.CharField(
                        choices=[("STRUCTURAL", "Structural"), ("NON_STRUCTURAL", "Non Structural")],
                        max_length=64,
                        verbose_name="Type",
                    ),
                ),
                (
                    "severity",
                    models.CharField(
                        choices=[
                            ("MINOR", "Minor"),
                            ("MODERATE", "Moderate"),
                            ("SEVERE", "Severe"),
                            ("Very SEVERE", "Very Severe"),
                        ],
                        max_length=64,
                        verbose_name="Severity",
                    ),
                ),
                (
                    "flag",
                    models.CharField(
                        choices=[
                            ("GREEN", "Green"),
                            ("YELLO", "Yellow"),
                            ("ORANGE", "Orange"),
                            ("RED", "Red"),
                            ("UNKNOWN", "Unknown"),
                        ],
                        max_length=64,
                        verbose_name="Flag",
                    ),
                ),
                ("direct_involvement", models.BooleanField(default=True, verbose_name="Direct Involvement")),
                ("company_response", models.CharField(blank=True, max_length=512, null=True)),
                ("review", models.DateField(verbose_name="Reviewed")),
                ("initiated", models.DateField(verbose_name="initiated")),
                ("instrument", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to="wbfdm.instrument")),
            ],
        ),
    ]
